@@ -219,6 +219,8 @@ DPXOutput::open(const std::string& name, const ImageSpec& userspec,
     m_stream = new OutStream();
     if (!m_stream->Open(name.c_str())) {
         error("Could not open file \"%s\"", name.c_str());
+        delete m_stream;
+        m_stream = nullptr;
         return false;
     }
     m_dpx.SetOutStream(m_stream);
@@ -695,6 +697,8 @@ DPXOutput::get_characteristic_from_string(const std::string& str)
         return dpx::kZLinear;
     else if (Strutil::iequals(str, "Z depth homogeneous"))
         return dpx::kZHomogeneous;
+    else if (Strutil::iequals(str, "ADX"))
+        return dpx::kADX;
     else
         return dpx::kUndefinedCharacteristic;
 }
