@@ -58,16 +58,6 @@
 
 #include "imageio_pvt.h"
 
-#ifdef USE_BOOST_REGEX
-#    include <boost/regex.hpp>
-using boost::regex;
-using boost::regex_replace;
-#else
-#    include <regex>
-using std::regex;
-using std::regex_replace;
-#endif
-
 using namespace OIIO;
 
 
@@ -891,6 +881,74 @@ write_mipmap(ImageBufAlgo::MakeTextureMode mode, std::shared_ptr<ImageBuf>& img,
 
 
 
+// Deconstruct the command line string, stripping directory names off of
+// any arguments. This is used for "update mode" to not think it's doing
+// a fresh maketx for relative paths and whatnot.
+static std::string
+stripdir_cmd_line(string_view cmdline)
+{
+    std::string out;
+    bool firstarg = true;
+    int skipstrip = 0;
+    while (!cmdline.empty()) {
+        if (!firstarg)
+            out += ' ';
+
+        // Grab the next word or quoted string
+        string_view s;
+        if (!Strutil::parse_string(cmdline, s))
+            break;
+
+        // Uniformize commands that start with '-' and those that start
+        // with '--'.
+        if (Strutil::starts_with(s, "--"))
+            s.remove_prefix(1);
+
+        std::string stripped = s;
+
+        // Some commands are known to be followed by arguments that might
+        // contain slashes, yet not be filenames. Remember to skip those.
+        // In particular, we're looking for things that might have arbitrary
+        // strings including slashes, for example, attribute names and color
+        // space names.
+        if (Strutil::starts_with(s, "-")) {
+            static const char* one_arg_list[]
+                = { "-colorconfig", "-iscolorspace",      "-tocolorspace",
+                    "-ociolook",    "-ociofiletransform", "-eraseattrib",
+                    "-caption",     "-keyword",           "-text",
+                    "-echo" };
+            static const char* two_arg_list[] = { "-attrib", "-sattrib",
+                                                  "-iconfig", "-colorconvert",
+                                                  "-ociodisplay" };
+            for (auto cmd : one_arg_list)
+                if (Strutil::starts_with(s, cmd))
+                    skipstrip = 2;  // including the command itself
+            for (auto cmd : two_arg_list)
+                if (Strutil::starts_with(s, cmd))
+                    skipstrip = 3;  // including the command itself
+        }
+
+        // Whatever's left when we're not disabling stripping for this arg,
+        // for anything that looks like a filename by having directory
+        // separators, strip out the directory name so that command lines
+        // appear to match even if filenames have different relative paths.
+        if (!skipstrip)
+            stripped = Filesystem::filename(stripped);
+
+        // Add the maybe-stripped string to the output, surrounding by
+        // double quotes if it contains any spaces.
+        if (stripped.find(' ') != std::string::npos)
+            out += Strutil::sprintf("\"%s\"", stripped);
+        else
+            out += stripped;
+        firstarg  = false;
+        skipstrip = std::max(0, skipstrip - 1);
+    }
+    return out;
+}
+
+
+
 static bool
 make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
                   std::string filename, std::string outputfilename,
@@ -989,7 +1047,9 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
         }
         std::string newcmdline = configspec.get_string_attribute(
             "maketx:full_command_line");
-        if (lastcmdline.size() && lastcmdline == newcmdline) {
+        if (lastcmdline.size()
+            && stripdir_cmd_line(lastcmdline)
+                   == stripdir_cmd_line(newcmdline)) {
             outstream << "maketx: no update required for \"" << outputfilename
                       << "\"\n";
             return true;
@@ -1570,17 +1630,12 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
 
     // Eliminate any SHA-1 or ConstantColor hints in the ImageDescription.
     if (desc.size()) {
-        desc = regex_replace(desc, regex("SHA-1=[[:xdigit:]]*[ ]*"), "");
-        static const char* fp_number_pattern
-            = "([+-]?((?:(?:[[:digit:]]*\\.)?[[:digit:]]+(?:[eE][+-]?[[:digit:]]+)?)))";
-        const std::string constcolor_pattern
-            = std::string("ConstantColor=(\\[?") + fp_number_pattern
-              + ",?)+\\]?[ ]*";
-        const std::string average_pattern = std::string("AverageColor=(\\[?")
-                                            + fp_number_pattern
-                                            + ",?)+\\]?[ ]*";
-        desc        = regex_replace(desc, regex(constcolor_pattern), "");
-        desc        = regex_replace(desc, regex(average_pattern), "");
+        Strutil::excise_string_after_head(desc, "oiio:ConstantColor=");
+        Strutil::excise_string_after_head(desc, "ConstantColor=");
+        Strutil::excise_string_after_head(desc, "oiio:AverageColor=");
+        Strutil::excise_string_after_head(desc, "AverageColor=");
+        Strutil::excise_string_after_head(desc, "oiio:SHA-1=");
+        Strutil::excise_string_after_head(desc, "SHA-1=");
         updatedDesc = true;
     }
 
