@@ -59,9 +59,14 @@ bool
 ImageOutput_write_scanline(ImageOutput& self, int y, int z, py::buffer& buffer)
 {
     const ImageSpec& spec(self.spec());
+    if (spec.tile_width != 0) {
+        self.errorf("Cannot write scanlines to a filed file.");
+        return false;
+    }
     oiio_bufinfo buf(buffer.request(), spec.nchannels, spec.width, 1, 1, 1);
-    if (!buf.data) {
-        self.error("Could not decode python buffer");
+    if (!buf.data || buf.error.size()) {
+        self.errorf("Pixel data array error: %s",
+                    buf.error.size() ? buf.error.c_str() : "unspecified");
         return false;  // failed sanity checks
     }
     if (static_cast<int>(buf.size)
@@ -80,10 +85,15 @@ ImageOutput_write_scanlines(ImageOutput& self, int ybegin, int yend, int z,
                             py::buffer& buffer)
 {
     const ImageSpec& spec(self.spec());
+    if (spec.tile_width != 0) {
+        self.errorf("Cannot write scanlines to a filed file.");
+        return false;
+    }
     oiio_bufinfo buf(buffer.request(), spec.nchannels, spec.width,
                      yend - ybegin, 1, 2);
-    if (!buf.data) {
-        self.error("Could not decode python buffer");
+    if (!buf.data || buf.error.size()) {
+        self.errorf("Pixel data array error: %s",
+                    buf.error.size() ? buf.error.c_str() : "unspecified");
         return false;  // failed sanity checks
     }
     if (static_cast<int>(buf.size)
@@ -103,11 +113,16 @@ ImageOutput_write_tile(ImageOutput& self, int x, int y, int z,
                        py::buffer& buffer)
 {
     const ImageSpec& spec(self.spec());
+    if (spec.tile_width == 0) {
+        self.errorf("Cannot write tiles to a scanline file.");
+        return false;
+    }
     oiio_bufinfo buf(buffer.request(), spec.nchannels, spec.tile_width,
                      spec.tile_height, spec.tile_depth,
                      spec.tile_depth > 1 ? 3 : 2);
-    if (!buf.data) {
-        self.error("Could not decode python buffer");
+    if (!buf.data || buf.error.size()) {
+        self.errorf("Pixel data array error: %s",
+                    buf.error.size() ? buf.error.c_str() : "unspecified");
         return false;  // failed sanity checks
     }
     if (buf.size < self.spec().tile_pixels() * self.spec().nchannels) {
@@ -126,10 +141,15 @@ ImageOutput_write_tiles(ImageOutput& self, int xbegin, int xend, int ybegin,
                         int yend, int zbegin, int zend, py::buffer& buffer)
 {
     const ImageSpec& spec(self.spec());
+    if (spec.tile_width == 0) {
+        self.errorf("Cannot write tiles to a scanline file.");
+        return false;
+    }
     oiio_bufinfo buf(buffer.request(), spec.nchannels, xend - xbegin,
                      yend - ybegin, zend - zbegin, spec.tile_depth > 1 ? 3 : 2);
-    if (!buf.data) {
-        self.error("Could not decode python buffer");
+    if (!buf.data || buf.error.size()) {
+        self.errorf("Pixel data array error: %s",
+                    buf.error.size() ? buf.error.c_str() : "unspecified");
         return false;  // failed sanity checks
     }
     if (static_cast<int>(buf.size) < (xend - xbegin) * (yend - ybegin)
@@ -152,8 +172,12 @@ ImageOutput_write_image(ImageOutput& self, py::buffer& buffer)
     const ImageSpec& spec(self.spec());
     oiio_bufinfo buf(buffer.request(), spec.nchannels, spec.width, spec.height,
                      spec.depth, spec.depth > 1 ? 3 : 2);
-    if (!buf.data || buf.size < spec.image_pixels() * spec.nchannels)
+    if (!buf.data || buf.size < spec.image_pixels() * spec.nchannels
+        || buf.error.size()) {
+        self.errorf("Pixel data array error: %s",
+                    buf.error.size() ? buf.error.c_str() : "unspecified");
         return false;  // failed sanity checks
+    }
     py::gil_scoped_release gil;
     return self.write_image(buf.format, buf.data, buf.xstride, buf.ystride,
                             buf.zstride);
@@ -196,39 +220,42 @@ declare_imageoutput(py::module& m)
     using namespace pybind11::literals;
 
     py::class_<ImageOutput>(m, "ImageOutput")
-        .def_static("create",
-                    [](const std::string& filename,
-                       const std::string& searchpath) -> py::object {
-                        auto out(ImageOutput::create(filename, searchpath));
-                        return out ? py::cast(out.release()) : py::none();
-                    },
-                    "filename"_a, "plugin_searchpath"_a = "")
+        .def_static(
+            "create",
+            [](const std::string& filename,
+               const std::string& searchpath) -> py::object {
+                auto out(ImageOutput::create(filename, searchpath));
+                return out ? py::cast(out.release()) : py::none();
+            },
+            "filename"_a, "plugin_searchpath"_a = "")
         .def("format_name", &ImageOutput::format_name)
         .def("supports",
              [](const ImageOutput& self, const std::string& feature) {
                  return self.supports(feature);
              })
         .def("spec", &ImageOutput::spec)
-        .def("open",
-             [](ImageOutput& self, const std::string& name,
-                const ImageSpec& newspec, const std::string& modestr) {
-                 ImageOutput::OpenMode mode = ImageOutput::Create;
-                 if (Strutil::iequals(modestr, "AppendSubimage"))
-                     mode = ImageOutput::AppendSubimage;
-                 else if (Strutil::iequals(modestr, "AppendMIPLevel"))
-                     mode = ImageOutput::AppendMIPLevel;
-                 else if (!Strutil::iequals(modestr, "Create"))
-                     throw std::invalid_argument(
-                         Strutil::sprintf("Unknown open mode '%s'", modestr));
-                 return self.open(name, newspec, mode);
-             },
-             "filename"_a, "spec"_a, "mode"_a = "Create")
-        .def("open",
-             [](ImageOutput& self, const std::string& name,
-                const std::vector<ImageSpec>& specs) {
-                 return self.open(name, (int)specs.size(), &specs[0]);
-             },
-             "filename"_a, "specs"_a)
+        .def(
+            "open",
+            [](ImageOutput& self, const std::string& name,
+               const ImageSpec& newspec, const std::string& modestr) {
+                ImageOutput::OpenMode mode = ImageOutput::Create;
+                if (Strutil::iequals(modestr, "AppendSubimage"))
+                    mode = ImageOutput::AppendSubimage;
+                else if (Strutil::iequals(modestr, "AppendMIPLevel"))
+                    mode = ImageOutput::AppendMIPLevel;
+                else if (!Strutil::iequals(modestr, "Create"))
+                    throw std::invalid_argument(
+                        Strutil::sprintf("Unknown open mode '%s'", modestr));
+                return self.open(name, newspec, mode);
+            },
+            "filename"_a, "spec"_a, "mode"_a = "Create")
+        .def(
+            "open",
+            [](ImageOutput& self, const std::string& name,
+               const std::vector<ImageSpec>& specs) {
+                return self.open(name, (int)specs.size(), &specs[0]);
+            },
+            "filename"_a, "specs"_a)
         .def("open", &ImageOutput_open_specs)
         .def("close", [](ImageOutput& self) { return self.close(); })
         .def("write_image", &ImageOutput_write_image)
